<?php
// 引入数据库配置文件
require_once '../config.php';

// 设置响应头为JSON
header('Content-Type: application/json');

// 清除Redis缓存
$redisManager = get_redis_instance();
$success = false;
$cleared = 0;
$debug_info = [];

if ($redisManager->isAvailable()) {
    $redis = $redisManager->getRedis();

    // 保存当前前缀设置
    $currentPrefix = '';
    try {
        $currentPrefix = $redis->getOption(Redis::OPT_PREFIX);
        // 暂时取消前缀
        $redis->setOption(Redis::OPT_PREFIX, '');
    } catch (Exception $e) {
        $debug_info['prefix_error'] = $e->getMessage();
    }

    // 使用更精确的模式查找商品列表相关的键
    try {
        // 更精确的商品列表缓存键模式
        $productListPatterns = [
            "*products:list:*",      // 匹配商品列表缓存
            "*product*:list:*",      // 可能的变体
            "ca417:db0:ca417_products:list:*" // 完全匹配从客户端看到的格式
        ];

        $totalFoundKeys = [];

        foreach ($productListPatterns as $pattern) {
            $keys = $redis->keys($pattern);
            if (is_array($keys) && !empty($keys)) {
                $totalFoundKeys = array_merge($totalFoundKeys, $keys);
            }
        }

        // 去重
        $totalFoundKeys = array_unique($totalFoundKeys);
        $debug_info['found_keys'] = $totalFoundKeys;

        // 验证是否确实是商品列表键
        $confirmedKeys = [];
        foreach ($totalFoundKeys as $key) {
            // 验证键名是否确实与商品列表相关
            if (
                strpos($key, 'products:list') !== false ||
                strpos($key, 'product:list') !== false ||
                (strpos($key, 'list') !== false && strpos($key, 'product') !== false)
            ) {
                $confirmedKeys[] = $key;
                $redis->del($key);
                $cleared++;
                $success = true;
            }
        }

        $debug_info['confirmed_keys'] = $confirmedKeys;

        // 恢复原前缀
        if ($currentPrefix) {
            $redis->setOption(Redis::OPT_PREFIX, $currentPrefix);
        }
    } catch (Exception $e) {
        $debug_info['delete_error'] = $e->getMessage();
    }
}

// 返回结果
echo json_encode([
    'success' => $success,
    'cleared' => $cleared,
    'message' => $success ? "已清除 $cleared 个商品列表缓存" : "无需清除缓存或Redis不可用",
    'debug_info' => $debug_info
], JSON_UNESCAPED_UNICODE);
