<?php
// list_users.php
session_start();
if (!isset($_SESSION['user'])) {
    header("Location: login.php");
    exit;
}

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$whereClause = '';
if (!empty($search)) {
    $search = $conn->real_escape_string($search);
    $whereClause = "WHERE username LIKE '%$search%' OR role LIKE '%$search%'";
}

// 获取提示消息
$message = isset($_GET['message']) ? $_GET['message'] : '';

// 定义角色名称映射
$roleMappings = [
    'admin' => '系统管理员',
    'finance' => '财务',
    'user' => '普通用户'
];

$sql = "SELECT id, username, real_name, phone, role, is_active, created_at FROM users $whereClause ORDER BY id DESC";
$result = $conn->query($sql);
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>用户列表</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>用户列表</h2>
        <div class="button-group">
            <a href="add_user.php" class="btn btn-add">添加用户</a>
        </div>
    </div>

    <?php if (!empty($message)): ?>
        <div class="message" id="message-box">
            <?= htmlspecialchars($message) ?>
            <button onclick="document.getElementById('message-box').style.display='none'">×</button>
        </div>
    <?php endif; ?>

    <form method="get" class="search-box">
        <input type="text" name="search" placeholder="搜索用户名/角色" value="<?= htmlspecialchars($search) ?>">
        <button type="submit">搜索</button>
    </form>

    <div class="table-container">
        <table>
            <thead>
                <tr>
                    <th>ID</th>
                    <th>用户名</th>
                    <th>姓名</th>
                    <th>手机号码</th>
                    <th>角色</th>
                    <th>状态</th>
                    <th>创建时间</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($result->num_rows > 0): ?>
                    <?php while ($row = $result->fetch_assoc()): ?>
                        <tr>
                            <td><?= $row['id'] ?></td>
                            <td><?= htmlspecialchars($row['username']) ?></td>
                            <td><?= htmlspecialchars($row['real_name'] ?: '-') ?></td>
                            <td><?= htmlspecialchars($row['phone'] ?: '-') ?></td>
                            <td><?= htmlspecialchars($roleMappings[$row['role']] ?? $row['role']) ?></td>
                            <td><?= $row['is_active'] ? '启用' : '禁用' ?></td>
                            <td><?= $row['created_at'] ?></td>
                            <td>
                                <a href="edit_user.php?id=<?= $row['id'] ?>" class="btn">编辑</a>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" style="text-align:center; padding: 30px;">暂无用户数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</body>

</html>